(robprofile) ไลบรารี่สำหรับใช้เป็นตัวอย่างในการ up load PyPi:
https://pypi.org/project/robprofile/

เป็น pakage อธิบายการ up load PYPI

วิธีติดตั้ง เปิด CMD / Terminal

pip install robprofile วิธีใช้งานแพ็คเพจนี้ เปิด IDLE ขึ้นมาแล้วพิมพ์…
‘’’ python my = Profile(‘Rob’) my.company = ‘CPF’ my.hobby =
[‘Reading’,‘Sleeping’,‘Eating’] print(my.name) my.show_email()
my.show_myart() my.show_hobby() ‘’’ พัฒนาโดย: Rob Noiin
